==> qbs-windows-x86_64-1.8.0.zip: qbs-windows-x86_64-1.8.0/include/qbs/qtenvironment.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_QTENVIRONMENT_H
#define QBS_QTENVIRONMENT_H

#include <tools/qbs_export.h>

#include <QtCore/qstringlist.h>

namespace qbs {

class QBS_EXPORT QtEnvironment {
public:
    QString installPrefixPath;
    QString libraryPath;
    QString includePath;
    QString binaryPath;
    QString qmlPath;
    QString qmlImportPath;
    QString documentationPath;
    QString dataPath;
    QString pluginPath;
    QString qtLibInfix;
    QString qtNameSpace;
    QString mkspecPath;
    QString mkspecName;
    QString mkspecBasePath;
    QStringList entryPointLibsDebug;
    QStringList entryPointLibsRelease;
    QStringList buildVariant;
    QStringList configItems;
    QStringList qtConfigItems;
    QString architecture;
    QString qtVersion;
    int qtMajorVersion;
    int qtMinorVersion;
    int qtPatchVersion;
    bool staticBuild = false;
    bool frameworkBuild = false;
};

} // namespace qbs

#endif // Include guard.

==> qbs-windows-x86_64-1.9.1.zip: qbs-windows-x86_64-1.9.1/include/qbs/qtenvironment.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_QTENVIRONMENT_H
#define QBS_QTENVIRONMENT_H

#include <tools/qbs_export.h>
#include <tools/version.h>

#include <QtCore/qstringlist.h>

namespace qbs {

class QBS_EXPORT QtEnvironment {
public:
    QString installPrefixPath;
    QString libraryPath;
    QString includePath;
    QString binaryPath;
    QString qmlPath;
    QString qmlImportPath;
    QString documentationPath;
    QString dataPath;
    QString pluginPath;
    QString qtLibInfix;
    QString qtNameSpace;
    QString mkspecPath;
    QString mkspecName;
    QString mkspecBasePath;
    QStringList entryPointLibsDebug;
    QStringList entryPointLibsRelease;
    QStringList buildVariant;
    QStringList configItems;
    QStringList qtConfigItems;
    QString architecture;
    QString qtVersion;
    QString windowsVersion;
    QString macosVersion;
    QString iosVersion;
    QString androidVersion;
    int qtMajorVersion;
    int qtMinorVersion;
    int qtPatchVersion;
    Internal::Version msvcVersion;
    bool staticBuild = false;
    bool frameworkBuild = false;
};

} // namespace qbs

#endif // Include guard.
